## Note

These are generally command-line apps.  This is done because we frequently want to run codes on computing clusters, which require we interact via bash and command line, instead of the interpreter.